#ifndef NT2_INCLUDE_FUNCTIONS_FLOOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FLOOR_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/floor.hpp>

#endif
